@@ -10,7 +10,7 @@ from dpymenus.constants import QUIT
 from dpymenus.exceptions import PagesError
 from dpymenus.page import Page
 
-active_users = list()
+sessions = list()
 
 
 class BaseMenu:
@@ -43,8 +43,8 @@ class BaseMenu:
         self.data = None
 
     def __repr__(self):
-        return f'<Menu pages={[p.__str__() for p in self.pages]}, timeout={self.timeout}, ' \
-               f'active={self.active} page={self.page_index}>'
+        return f'BaseMenu(pages={[p.__str__() for p in self.pages]}, timeout={self.timeout}, ' \
+               f'active={self.active} page={self.page_index})'
 
     async def open(self):
         """The entry point to a new TextMenu instance; starts the main menu loop.
@@ -76,13 +76,16 @@ class BaseMenu:
 
         #  if the next page has no on_next callback, we end the menu loop
         if self.page.on_next is None:
-            await self.set_user_inactive()
+            await self.close_session()
             self.active = False
 
         await self.send_message(self.page)
 
     async def previous(self):
         """Helper method for quickly accessing the previous page."""
+        if self.page_index - 1 < 0:
+            return
+
         self.page_index -= 1
         self.page = self.pages[self.page_index]
 
@@ -123,28 +126,27 @@ class BaseMenu:
 
     async def cancel(self):
         """Sends a cancellation message."""
+        embed = Embed(title=self.page.title, description='Menu selection cancelled.', color=Colour.red())
+
         if self.page.on_cancel:
             return await self.page.on_cancel()
 
-        embed = Embed(title=self.page.title, description='Menu selection cancelled.', color=Colour.red())
+        if hasattr(self, 'on_cancel'):
+            embed = self.on_cancel
+
         await self.send_message(embed)
-        await self.set_user_inactive()
+        await self.close_session()
         self.active = False
 
     async def get_next_page(self) -> Page:
         """Utility method that returns the next page based on the current pages index."""
         return self.pages[self.page_index + 1]
 
+    async def close_session(self):
+        """Remove the user from the active users list."""
+        sessions.remove((self.ctx.author.id, self.ctx.channel.id))
+
     # Internal Methods
-    async def validate_user(self) -> bool:
-        return False if self.ctx.author in active_users else True
-
-    async def set_user_active(self):
-        active_users.append(self.ctx.author)
-
-    async def set_user_inactive(self):
-        active_users.remove(self.ctx.author)
-
     async def _cleanup_input(self):
         """Deletes a Discord client user message."""
         if isinstance(self.ctx.channel, GuildChannel):
@@ -152,14 +154,17 @@ class BaseMenu:
 
     async def _timeout(self):
         """Sends a timeout message."""
-        await self.set_user_inactive()
-        self.active = False
+        embed = Embed(title='Timed Out', description='You timed out at menu selection.', color=Colour.red())
 
         if self.page.on_timeout:
             return await self.page.on_timeout()
 
-        embed = Embed(title=self.page.title, description='You timed out at menu selection.', color=Colour.red())
+        if hasattr(self, 'on_timeout'):
+            embed = self.on_timeout
+
         await self.send_message(embed)
+        await self.close_session()
+        self.active = False
 
     async def _is_cancelled(self) -> bool:
         """Checks input for a cancellation string. If there is a match, it calls the ``menu.cancel()`` method and returns True."""
@@ -171,7 +176,9 @@ class BaseMenu:
     async def _get_input(self) -> Message:
         """Collects user input and places it into the input attribute."""
         try:
-            message = await self.ctx.bot.wait_for('message', timeout=self.timeout, check=lambda m: m.author == self.ctx.author)
+            message = await self.ctx.bot.wait_for('message', timeout=self.timeout,
+                                                  check=lambda m: m.author == self.ctx.author
+                                                  and self.ctx.channel == m.channel)
 
         except asyncio.TimeoutError:
             if self.page.on_timeout:
@@ -187,3 +194,10 @@ class BaseMenu:
         """Checks that the Menu contains at least one Page."""
         if len(self.pages) <= 1:
             raise PagesError(f'There must be more than one page in a menu. Expected at least 2, found {len(self.pages)}.')
+
+    async def _start_session(self) -> bool:
+        if (self.ctx.author.id, self.ctx.channel.id) in sessions:
+            return False
+
+        sessions.append((self.ctx.author.id, self.ctx.channel.id))
+        return True
