@@ -24,8 +24,8 @@ class ButtonMenu(BaseMenu):
         self.data = data if data else {}
 
     def __repr__(self):
-        return f'<Menu pages={[p.__str__() for p in self.pages]}, timeout={self.timeout}, ' \
-               f'active={self.active} page={self.page_index}, data={self.data}>'
+        return f'ButtonMenu(pages={[p.__str__() for p in self.pages]}, timeout={self.timeout}, ' \
+               f'active={self.active} page={self.page_index}, data={self.data})'
 
     async def open(self):
         """The entry point to a new TextMenu instance; starts the main menu loop.
@@ -33,11 +33,9 @@ class ButtonMenu(BaseMenu):
         await super()._validate_pages()
         await self._validate_buttons()
 
-        if not await super().validate_user():
+        if await self._start_session() is False:
             return
 
-        await super().set_user_active()
-
         self.output = await self.ctx.send(embed=self.page)
 
         while self.active:
@@ -57,7 +55,11 @@ class ButtonMenu(BaseMenu):
     async def _get_reaction(self) -> Union[Emoji, str]:
         """Collects a user reaction and places it into the input attribute. Returns an Emoji or Emoji name."""
         try:
-            reaction, user = await self.ctx.bot.wait_for('reaction_add', timeout=self.timeout, check=lambda _, u: u == self.ctx.author)
+            reaction, user = await self.ctx.bot.wait_for('reaction_add', timeout=self.timeout,
+                                                         check=lambda r, u: u == self.ctx.author
+                                                         and self.ctx.channel == r.message.channel
+                                                         and r.message.id == self.output.id)
+
         except asyncio.TimeoutError:
             await self._timeout()
 
